@@ -10,7 +10,7 @@ class AtfFileAttachment(BaseModel):
     path = models.CharField(db_column="Path", max_length=500)
     date_create = models.DateTimeField(db_column="DateCreate", default=timezone.now)
     create_username = models.CharField(db_column="CreateUserName", max_length=255, default="")
-    create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", default=0, **FK_DEFAULT)
+    create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
     file_info = models.ForeignKey(
         "AtfFileInfo",
         models.DO_NOTHING,
