@@ -6,7 +6,7 @@ from django.db import models
 # noinspection PyUnresolvedReferences
 from django.utils import timezone
 
-FK_DEFAULT = {"on_delete": models.DO_NOTHING, "related_name": "+", "blank": True}
+FK_DEFAULT = {"on_delete": models.DO_NOTHING, "related_name": "+", "default": 0}
 
 
 class BaseModel(models.Model):
